@@ -91,9 +91,7 @@ def nal_sev(data, cols, cols_rvs):
 
 
 @njit(fastmath=True)
-def nal_counter(data, arities, cols, alpha=0.3, samplesize=None):
-    if samplesize == None:
-        samplesize = data.shape[0]
+def nal_counter(data, arities, cols, alpha=0.3):
     strides = np.empty(len(cols), dtype=np.uint32)
     idx = len(cols) - 1
     stride = 1
@@ -125,7 +123,7 @@ def nal_counter(data, arities, cols, alpha=0.3, samplesize=None):
             nal += N_ijk[i] * np.log(N_ijk[i] / N_ij[i])
     nal /= np.sum(N_ijk)
     # nal -= 0.5 * np.log(np.sum(N_ijk)) / np.sum(N_ijk) * (arities[cols[0]] - 1) * strides[0]
-    nal -= 1 / data.shape[1] * np.power(samplesize, -alpha) * (arities[cols[0]] - 1) * strides[0]
+    nal -= 1 / data.shape[1] * np.power(np.sum(N_ijk), -alpha) * (arities[cols[0]] - 1) * strides[0]
     return nal
 
 
